@@ -19,19 +19,20 @@
 #include "config.h"
 #endif
 
-#include <string.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/mman.h>
 #include <endian.h>
+#include <errno.h>
+#include <error.h>
+#include <fcntl.h>
+#include <gelf.h>
+#include <libelf.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <error.h>
-#include <libelf.h>
-#include <gelf.h>
+#include <string.h>
+#include <sys/mman.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #ifndef _
 #define _(x) x
@@ -44,9 +45,6 @@
 
 static_assert (sizeof (unsigned long) >= sizeof (uint32_t));
 
-typedef int bool;
-static const bool false = 0, true = 1;
-
 /* This is bfd_calc_gnu_debuglink_crc32 from bfd/opncls.c.  */
 static unsigned long
     calc_gnu_debuglink_crc32 (unsigned long crc,
@@ -139,7 +137,7 @@ crc32 (const char *fname, const char *base_fname, uint32_t *crcp)
       error (0, errno, _("cannot open \"%s\""), debugname);
       return false;
     }
-  off64_t size = lseek64 (fd, 0, SEEK_END);
+  off_t size = lseek (fd, 0, SEEK_END);
   if (size == -1)
     {
       error (0, errno, _("cannot get size of \"%s\""), debugname);
@@ -258,10 +256,13 @@ process (Elf *elf, int fd, const char *fname)
 	  continue;
 	}
       const uint8_t *zerop = memchr (data->d_buf, '\0', data->d_size);
-      const uint8_t *crcp = (zerop == NULL
-			     ? NULL
-			     : (const uint8_t *) ((uintptr_t) (zerop + 1 + 3)
-						  & -4));
+      if (zerop == NULL)
+	{
+	  error (0, 0, _("no file string in section \"%s\" # %zu in \"%s\""),
+		 scnname, elf_ndxscn (scn), fname);
+	  continue;
+	}
+      const uint8_t *crcp = (const uint8_t *) ((uintptr_t) (zerop + 1 + 3) & -4);
       if (crcp + 4 != (uint8_t *) data->d_buf + data->d_size)
 	{
 	  error (0, 0, _("invalid format of section \"%s\" # %zu in \"%s\""),
@@ -281,7 +282,7 @@ process (Elf *elf, int fd, const char *fname)
 	  return true;
 	}
       updated_count++;
-      off64_t seekto = (shdr->sh_offset + data->d_off
+      off_t seekto = (shdr->sh_offset + data->d_off
 			+ (crcp - (const uint8_t *) data->d_buf));
       uint32_t crc_targetendian = (ehdr->e_ident[EI_DATA] == ELFDATA2LSB
 				   ? htole32 (crc) : htobe32 (crc));
@@ -349,10 +350,11 @@ main (int argc, char **argv)
 	}
 
       /* Make sure we can read and write */
-      chmod (fname, stat_buf.st_mode | S_IRUSR | S_IWUSR);
+      if (chmod (fname, stat_buf.st_mode | S_IRUSR | S_IWUSR) != 0)
+	error (0, errno, _("cannot chmod \"%s\" to make sure we can read and write"), fname);
 
       bool failed = false;
-      int fd = open64 (fname, O_RDWR);
+      int fd = open (fname, O_RDWR);
       if (fd == -1)
 	{
 	  error (0, errno, _("cannot open \"%s\""), fname);
@@ -386,7 +388,8 @@ main (int argc, char **argv)
 	}
 
       /* Restore old access rights. Including any suid bits reset. */
-      chmod (fname, stat_buf.st_mode);
+      if (chmod (fname, stat_buf.st_mode) != 0)
+	error (0, errno, _("cannot chmod \"%s\" to restore old access rights"), fname);
 
       if (failed)
 	failed_count++;
